#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Nov  6 14:00:56 2018

@author:  Audiffren Julien 

@license : GNU GPL 3 https://www.gnu.org/licenses/gpl-3.0.en.html

    This file run the scoring algorithm on a given input to use it :

        python3 main.py  "name_of_the_file" {} {}

    where the first {} should be 1,2 or 3 and is the block length (parameter of the model)
    and the second {} should be OE or CE for respectively Open Eyes and Close Eyes

"""

import numpy as np
import argparse
from swarii import SWARII, WBB_parser
from gmm_classification import GMM_Score_predictor
import warnings
from plots import create_animated_stato, plot_score


warnings.filterwarnings("ignore")


if __name__ == "__main__":

    # Argument Parsing

    args = argparse.ArgumentParser()
    args.add_argument('input', metavar='input', type=str, nargs='+',
                       help='path of the input')
    args.add_argument('block_size', metavar='block_size', type=int, nargs='+',
                       help='time unit')
    args.add_argument('eyes', metavar='eyes', type=str, nargs='+',
                       help='OE or CE')

    
    error_message = ""

    parsed_args = args.parse_args()
    file_address = parsed_args.input[0]
    block_size = parsed_args.block_size[0]
    eyes_type = parsed_args.eyes[0]

    try :
        # Reading input
        data = WBB_parser.parse(file_address)

        #data[:,0]*=0.000001

        # Resampling
        data = np.array(SWARII.resample(data))
    
    except Exception as error:
        error_message = "Error regarding the input file. Please ensure that the input file has the correct format."
        with open("demo_failure.txt","wt+") as f :
            f.write(error_message)
            f.write(" Detailed error: {}".format(error))

    if len(error_message)== 0:

        # Scoring
        mygmm = GMM_Score_predictor(block_size=block_size,eye_type=eyes_type)
        scores = np.array(mygmm.predict(data))

        average_score = np.mean(scores)

        #probabilities are multiplied by 100 just for the sake of readability by the user
        average_score = int(100*(average_score))

        print("Average Score for the trajectory : {}".format(average_score))

        plot_score(average_score)
        create_animated_stato(data,scores,block_size*25,12)
